import React, { useState } from "react";
import {
  LayoutDashboard,
  DollarSign,
  BarChart3,
  // TrendingUp,
  ClipboardList,
  Zap, // Importing new icon for Transmission Latest
  Clock, // Importing new icon for Transmission Hourly
  ArrowRightCircle, // Importing new icon for Border Capacity
  LineChart,
} from "lucide-react";
import Dashboard from "./components/Dashboard";
import Price from "./components/Price"; // Import the Price component
// import GroupPriceLatest from "./components/GroupPriceLatest";
// import GroupPriceCurrent from "./components/GroupPriceCurrent";
import Turnover from "./components/Turnover";
import PlannedTrade from "./components/PlannedTrade";
import PlannedTradeLatest from "./components/PlannedTradeLatest";
import TransmissionBorderCapacity from "./components/TransmissionBorderCapacity";
import TransmissionHourly from "./components/TransmissionHourly";
import TransmissionLatest from "./components/TransmissionLatest";
import GroupPrice from "./components/GroupPrice";
import GasBalanceChart from "./components/GasBalanceChart";

function App() {
  const [isSidebarOpen] = useState(true);
  const [activeTab, setActiveTab] = useState("dashboard"); // state to track the active tab

  return (
    <div className="flex h-screen bg-gray-100">
      <div
        className={`${
          isSidebarOpen ? "translate-x-0" : "-translate-x-full"
        } fixed lg:relative lg:translate-x-0 z-30 h-screen bg-white border-r transition-transform duration-300 ease-in-out`}
      >
        <div className="flex flex-col h-full w-64">
          <nav className="flex-1 px-4 py-6">
            <div className="space-y-2">
              <button
                onClick={() => setActiveTab("dashboard")}
                className={`w-full flex items-center space-x-2 px-4 py-2.5 text-sm font-medium rounded-lg ${
                  activeTab === "dashboard"
                    ? "bg-indigo-50 text-indigo-600"
                    : "text-gray-700 hover:bg-gray-50"
                }`}
              >
                <LayoutDashboard className="h-5 w-5" />
                <span>Dashboard</span>
              </button>
              <button
                onClick={() => setActiveTab("price")}
                className={`w-full flex items-center space-x-2 px-4 py-2.5 text-sm font-medium rounded-lg ${
                  activeTab === "price"
                    ? "bg-indigo-50 text-indigo-600"
                    : "text-gray-700 hover:bg-gray-50"
                }`}
              >
                <DollarSign className="h-5 w-5" />
                <span>Price</span>
              </button>
              <button
                onClick={() => setActiveTab("groupPrice")}
                className={`w-full flex items-center space-x-2 px-4 py-2.5 text-sm font-medium rounded-lg ${
                  activeTab === "groupPrice"
                    ? "bg-indigo-50 text-indigo-600"
                    : "text-gray-700 hover:bg-gray-50"
                }`}
              >
                <BarChart3 className="h-5 w-5" />
                <span>Group Price</span>
              </button>
              <button
                onClick={() => setActiveTab("gasBalance")}
                className={`w-full flex items-center space-x-2 px-4 py-2.5 text-sm font-medium rounded-lg ${
                  activeTab === "gasBalance"
                    ? "bg-indigo-50 text-indigo-600"
                    : "text-gray-700 hover:bg-gray-50"
                }`}
              >
                <LineChart className="h-5 w-5" />
                <span>Gas Balance</span>
              </button>
              {/* <button
                onClick={() => setActiveTab("turnover")}
                className={`w-full flex items-center space-x-2 px-4 py-2.5 text-sm font-medium rounded-lg ${
                  activeTab === "turnover"
                    ? "bg-indigo-50 text-indigo-600"
                    : "text-gray-700 hover:bg-gray-50"
                }`}
              >
                <TrendingUp className="h-5 w-5" />
                <span>Turnover</span>
              </button> */}
              <button
                onClick={() => setActiveTab("plannedTrade")}
                className={`w-full flex items-center space-x-2 px-4 py-2.5 text-sm font-medium rounded-lg ${
                  activeTab === "plannedTrade"
                    ? "bg-indigo-50 text-indigo-600"
                    : "text-gray-700 hover:bg-gray-50"
                }`}
              >
                <ClipboardList className="h-5 w-5" />
                <span>Planned Trade</span>
              </button>
              <button
                onClick={() => setActiveTab("plannedTradeLatest")}
                className={`w-full flex items-center space-x-2 px-4 py-2.5 text-sm font-medium rounded-lg ${
                  activeTab === "plannedTradeLatest"
                    ? "bg-indigo-50 text-indigo-600"
                    : "text-gray-700 hover:bg-gray-50"
                }`}
              >
                <ClipboardList className="h-5 w-5" />
                <span>Planned Trade Latest</span>
              </button>
              <button
                onClick={() => setActiveTab("borderCapacity")}
                className={`w-full flex items-center space-x-2 px-4 py-2.5 text-sm font-medium rounded-lg ${
                  activeTab === "borderCapacity"
                    ? "bg-indigo-50 text-indigo-600"
                    : "text-gray-700 hover:bg-gray-50"
                }`}
              >
                <ArrowRightCircle className="h-5 w-5" />{" "}
                {/* New icon for Border Capacity */}
                <span>Border Capacity</span>
              </button>
              <button
                onClick={() => setActiveTab("transmissionHourly")}
                className={`w-full flex items-center space-x-2 px-4 py-2.5 text-sm font-medium rounded-lg ${
                  activeTab === "transmissionHourly"
                    ? "bg-indigo-50 text-indigo-600"
                    : "text-gray-700 hover:bg-gray-50"
                }`}
              >
                <Clock className="h-5 w-5" />{" "}
                {/* New icon for Transmission Hourly */}
                <span>Hourly Transmission</span>
              </button>
              <button
                onClick={() => setActiveTab("transmissionLatest")}
                className={`w-full flex items-center space-x-2 px-4 py-2.5 text-sm font-medium rounded-lg ${
                  activeTab === "transmissionLatest"
                    ? "bg-indigo-50 text-indigo-600"
                    : "text-gray-700 hover:bg-gray-50"
                }`}
              >
                <Zap className="h-5 w-5" />{" "}
                {/* New icon for Transmission Latest */}
                <span>Latest Transmission</span>
              </button>
            </div>
          </nav>
        </div>
      </div>

      {/* Main Content */}
      <div className="flex-1 flex flex-col overflow-hidden">
        <main className="flex-1 overflow-x-hidden overflow-y-auto bg-gray-100 p-6">
          {/* Conditionally render components based on the active tab */}
          {activeTab === "dashboard" && <Dashboard />}
          {activeTab === "price" && <Price />}
          {activeTab === "groupPrice" && <GroupPrice />}
          {activeTab === "gasBalance" && <GasBalanceChart />}
          {activeTab === "turnover" && <Turnover />}
          {activeTab === "plannedTrade" && <PlannedTrade />}
          {activeTab === "plannedTradeLatest" && <PlannedTradeLatest />}
          {activeTab === "borderCapacity" && <TransmissionBorderCapacity />}
          {activeTab === "transmissionHourly" && <TransmissionHourly />}
          {activeTab === "transmissionLatest" && <TransmissionLatest />}
        </main>
      </div>
    </div>
  );
}

export default App;
